From be9816ee7cd57321d4097c8bc890ce37b87a7ead Mon Sep 17 00:00:00 2001
From: redray <redray@ispconfig3>
Date: Fri, 03 Oct 2008 09:25:48 -0400
Subject: [PATCH] 

---
 interface/web/sites/database_edit.php |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/interface/web/sites/database_edit.php b/interface/web/sites/database_edit.php
index 3dbaff8..d9b0181 100644
--- a/interface/web/sites/database_edit.php
+++ b/interface/web/sites/database_edit.php
@@ -192,11 +192,14 @@
 	function onUpdate() {
 		global $app, $conf;
 		
 		//* Prevent that the database name is changed
 		$old_record = $app->tform->getDataRecord($this->id);
 		if($old_record["database_name"] != $this->dataRecord["database_name"]) {
 			$app->tform->errorMessage .= $app->tform->wordbook["database_name_change_txt"].'<br />';
 		}
+		if($old_record["database_charset"] != $this->dataRecord["database_charset"]) {
+			$app->tform->errorMessage .= $app->tform->wordbook["database_charset_change_txt"].'<br />';
+		}
 		unset($old_record);
 		
 		parent::onUpdate();
@@ -192,11 +192,14 @@
 		global $app, $conf;
 		
-		//* Prevent that the database name is changed
+		//* Prevent that the database name and charset is changed
 		$old_record = $app->tform->getDataRecord($this->id);
 		if($old_record["database_name"] != $this->dataRecord["database_name"]) {

--
Gitblit v1.9.1